@@ -1,3 +1,4 @@
+from __future__ import unicode_literals
 
 from datetime import datetime, timedelta
 from optparse import make_option
@@ -41,7 +42,7 @@ class Command(BaseImporterCommand):
         query.max_results = 500
         try:
             feed = blogger.Get(query.ToUri())
-        except service.RequestError, err:
+        except service.RequestError as err:
             message = "There was a service error. The response was: " \
                 "%(status)s %(reason)s - %(body)s" % err.message
             raise CommandError(message, blogger.server + query.feed,
