@@ -1,4 +1,7 @@
+from __future__ import unicode_literals
+from future.builtins import int, zip
 
+from functools import reduce
 from operator import ior, iand
 from string import punctuation
 
@@ -8,9 +11,11 @@ from django.db.models.manager import ManagerDescriptor
 from django.db.models.query import QuerySet
 from django.contrib.sites.managers import CurrentSiteManager as DjangoCSM
 from django.utils.timezone import now
+from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.conf import settings
 from mezzanine.utils.sites import current_site_id
+from mezzanine.utils.urls import home_slug
 
 
 class PublishedManager(Manager):
@@ -48,7 +53,7 @@ def search_fields_to_dict(fields):
     if not fields:
         return {}
     try:
-        int(dict(fields).values()[0])
+        int(list(dict(fields).values())[0])
     except (TypeError, ValueError):
         fields = dict(zip(fields, [1] * len(fields)))
     return fields
@@ -238,7 +243,13 @@ class SearchableManager(Manager):
         any models that subclass from this manager's model if the
         model is abstract.
         """
-        if getattr(self.model._meta, "abstract", False):
+        if not settings.SEARCH_MODEL_CHOICES:
+            # No choices defined - build a list of leaf models (those
+            # without subclasses) that inherit from Displayable.
+            models = [m for m in get_models() if issubclass(m, self.model)]
+            parents = reduce(ior, [m._meta.get_parent_list() for m in models])
+            models = [m for m in models if m not in parents]
+        elif getattr(self.model._meta, "abstract", False):
             # When we're combining model subclasses for an abstract
             # model (eg Displayable), we only want to use models that
             # are represented by the ``SEARCH_MODEL_CHOICES`` setting.
@@ -314,4 +325,21 @@ class DisplayableManager(CurrentSiteManager, PublishedManager,
     and ``SearchableManager`` for the ``Displayable`` model.
 
     """
-    pass
+
+    def url_map(self, for_user=None, **kwargs):
+        """
+        Returns a dictionary of urls mapped to Displayable subclass
+        instances, including a fake homepage instance if none exists.
+        Used in ``mezzanine.core.sitemaps``.
+        """
+        home = self.model(title=_("Home"))
+        setattr(home, "get_absolute_url", home_slug)
+        items = {home.get_absolute_url(): home}
+        for model in get_models():
+            if issubclass(model, self.model):
+                for item in (model.objects.published(for_user=for_user)
+                                  .filter(**kwargs)
+                                  .exclude(slug__startswith="http://")
+                                  .exclude(slug__startswith="https://")):
+                    items[item.get_absolute_url()] = item
+        return items
